@@ -125,22 +125,7 @@ import Data.Attributes (newAttrsOnlyPos)
 import C2HS.Config (PlatformSpec(..))
 import C2HS.State  (CST, errorsPresent, showErrors, fatal,
                    SwitchBoard(..), Traces(..), putTraceStr, getSwitch)
-import C2HS.C     (AttrC, CObj(..), CTag(..),
-                   CDecl(..), CDeclSpec(..), CTypeSpec(..),
-                   CStructUnion(..), CStructTag(..), CEnum(..), CDeclr(..), CAttr(..),
-                   CDerivedDeclr(..),CArrSize(..),
-                   CExpr(..), CBinaryOp(..), CUnaryOp(..), CConst (..),
-                   CInteger(..),cInteger,getCInteger,getCCharAsInt,
-                   runCT, ifCTExc,
-                   raiseErrorCTExc, findValueObj, findFunObj, findTag,
-                   applyPrefixToNameSpaces,
-                   simplifyDecl, declrNamed, structMembers,
-                   structName, tagName, declaredName , structFromDecl,
-                   funResultAndArgs, chaseDecl, findAndChaseDecl,
-                   checkForAlias, checkForOneAliasName, checkForOneCUName,
-                   lookupEnum, lookupStructUnion, lookupDeclOrTag, isPtrDeclr,
-                   dropPtrDeclr, isPtrDecl, getDeclOf, isFunDeclr,
-                   refersToNewDef, partitionDeclSpecs, CDef(..))
+import C2HS.C
 
 -- friends
 import C2HS.CHS   (CHSModule(..), CHSFrag(..), CHSHook(..),
@@ -884,7 +869,7 @@ funDef isPure hsLexeme fiLexeme extTy octxt parms parm marsh2 pos =
                       interr "GenBind.funDef: marshRes: no default?"
 
       marshBody (Left ide) = identToString ide
-      marshBody (Right str) = str
+      marshBody (Right str) = "(" ++ str ++ ")"
 
       retArgs'  = case parm' of
                     CHSParm _ _ _ (Just (_, CHSVoidArg))   _ ->        retArgs
@@ -894,8 +879,8 @@ funDef isPure hsLexeme fiLexeme extTy octxt parms parm marsh2 pos =
       funBody   = joinLines marshIns  ++
                   mkMarsh2            ++
                   call                ++
-                  joinLines marshOuts ++
                   marshRes            ++
+                  joinLines marshOuts ++
                   "  " ++
                   (if isImpure || not isPure then "return " else "") ++ ret
     return $ sig ++ funHead ++ funBody
@@ -913,8 +898,8 @@ funDef isPure hsLexeme fiLexeme extTy octxt parms parm marsh2 pos =
         ctxt   = case octxt of
                    Nothing      -> ""
                    Just ctxtStr -> ctxtStr ++ " => "
-        argTys = [ty | CHSParm im ty _ _  _ <- parms'      , notVoid im]
-        resTys = [ty | CHSParm _  ty _ om _ <- parm':parms', notVoid om]
+        argTys = ["(" ++ ty ++ ")" | CHSParm im ty _ _  _ <- parms'      , notVoid im]
+        resTys = ["(" ++ ty ++ ")" | CHSParm _  ty _ om _ <- parm':parms', notVoid om]
         resTup = let
                    (lp, rp) = if isPure && length resTys == 1
                               then ("", "")
@@ -962,7 +947,7 @@ funDef isPure hsLexeme fiLexeme extTy octxt parms parm marsh2 pos =
         retArg   = if omArgKind == CHSVoidArg || omArgKind == CHSIOVoidArg then "" else outBndr
 
         marshBody (Left ide) = identToString ide
-        marshBody (Right str) = str
+        marshBody (Right str) = "(" ++ str ++ ")"
       in
       (funArg, marshIn, callArgs, marshOut, retArg)
     marshArg _ _ = interr "GenBind.funDef: Missing default?"
